pub fn check_send_escape(stmts: &[Stmt<'_>]) -> Vec<SendDiagnostic>Expand description
Run the Send/escape analysis over a whole program. An empty result means the program respects the message-passing + CRDT discipline.
pub fn check_send_escape(stmts: &[Stmt<'_>]) -> Vec<SendDiagnostic>Run the Send/escape analysis over a whole program. An empty result means the program respects the message-passing + CRDT discipline.